{% extends 'base.html' %}
{% load i18n %}
{% block title %}{{ name }}{% endblock %}

{% block page_header %}
    {% include "horizon/common/_page_header.html" with title=name %}
{% endblock page_header %}

{% block main %}
    {% include 'horizon/common/_workflow.html' %}
{% endblock %}
